==> haskell-hledger-lib-1.40-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.40
visibility:           public
id:                   hledger-lib-1.40-CJwIOLXwokrAKs0CQbDCJk
key:                  hledger-lib-1.40-CJwIOLXwokrAKs0CQbDCJk
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  a49e90caa38657da7cb54e2ac556137a
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Balancing Hledger.Data.Dates
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Hledger.Write.Csv Hledger.Write.Html Hledger.Write.Ods
    Hledger.Write.Spreadsheet Text.Tabular.AsciiWide

hidden-modules:       Text.WideString Paths_hledger_lib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.40-CJwIOLXwokrAKs0CQbDCJk
depends:
    Decimal-0.5.2-1TLmFAppZWOA8ldRyzVUiC
    Glob-0.10.2-EXjlSbqCMco1wUiI4xq3V7
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf
    aeson-pretty-0.8.10-FF3kbqs1WvtKfkblP58Xcl
    ansi-terminal-1.0.2-JhmKbae07oX7bHm2tOBr0F array-0.5.4.0
    base-4.17.2.1 base-compat-0.13.0-4bY7VGgUDQwFnN0OMsXbDp
    blaze-markup-0.8.3.0-1slEV1JTVXCHBVRvUtps3k bytestring-0.11.5.3
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    cassava-0.5.4.1-IlL8GBkt7ZLwaUFuWaj0P
    cassava-megaparsec-2.1.1-FFJHPqkBx29G1lZm9C57zM
    cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    colour-2.3.6-5kduP8EJo8q50TTkpFMjx8 containers-0.6.7
    data-default-0.7.1.2-LONLsSvT4G81IL8ks6Ql72 deepseq-1.4.8.0
    directory-1.3.7.1 doclayout-0.4.0.1-GUoJC0789ivIrg43gjVtj5
    extra-1.7.16-BWp1326BLeAsZES8r4M0Z
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashtables-1.4.1-IZn26iJgdHG2Am5hF18Tmr
    lucid-2.11.20250303-1MIfRvyKFhVJ4IlP33JQ49
    megaparsec-9.7.0-6xkhHCmKEAZB1EmG1WiH2F
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pager-0.1.1.0-JnFdT8fZ2M4LLx1JYjDPGm
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-D7LMPn9Xbgc1hYUqBdkbQ8
    regex-tdfa-1.3.2.4-6komq1p5pxY9JApKLJtftx
    safe-0.3.21-8UNW4gIoNRmKgGFufdPOla
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.5-FZEVHmEaz6e1recPNofOF8
    tasty-hunit-0.10.1-7oK5sIl4H3zIEPGFH1mHMV template-haskell-2.19.0.0
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2
    text-ansi-0.3.0.1-7GJ3dMZCRKDFKeulmhdnk1 time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    uglymemo-0.1.0.1-8AX9zjlFnnmIrnTboBgOzO
    unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.40-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.40
visibility:           public
id:                   hledger-lib-1.40-6EJJey6XIhw2E1CbcIqdb
key:                  hledger-lib-1.40-6EJJey6XIhw2E1CbcIqdb
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  8803b09a8e3b3abafa4f07a2ab2e02e9
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Balancing Hledger.Data.Dates
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Hledger.Write.Csv Hledger.Write.Html Hledger.Write.Ods
    Hledger.Write.Spreadsheet Text.Tabular.AsciiWide

hidden-modules:       Text.WideString Paths_hledger_lib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.40-6EJJey6XIhw2E1CbcIqdb
depends:
    Decimal-0.5.2-36PsXhmwtQk5hlFACGOX1e
    Glob-0.10.2-8KOKBxYCQYVKGt8mphTE6j
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    aeson-pretty-0.8.10-8K6VAOlgEiI6kbxgmBEhWH
    ansi-terminal-1.0.2-3ZetLec9Al83HbTC6rcVId array-0.5.4.0
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    blaze-markup-0.8.3.0-CJuRWkQj3FH3GFEjkD1DfK bytestring-0.11.5.3
    call-stack-0.4.0-IIJphBYRA8h64EHG5HU1qI
    cassava-0.5.4.1-F1QcoJtq6317FXXkU2DiVD
    cassava-megaparsec-2.1.1-7AZlBR7Vi5XBhdECWyNVQ8
    cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    colour-2.3.6-JQk97xPN0JfIXlQGuAtpoj containers-0.6.7
    data-default-0.7.1.2-LONLsSvT4G81IL8ks6Ql72 deepseq-1.4.8.0
    directory-1.3.7.1 doclayout-0.4.0.1-DVUOs5YOb9OE07EAvOs1f9
    extra-1.7.16-ARVAqO8RyG5El3VvrEfrR4
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashtables-1.4.1-IsxPnbWelw06pfvOT9iWgL
    lucid-2.11.20250303-EpaZp8AmEEO8HqQCng5yB6
    megaparsec-9.7.0-L9yzYQswnVIEfh0e6mQmZ2
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    pager-0.1.1.0-AQCAlnYUSVFGYwws5FiSm8
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-IojhPEFWmMPIri6V7Takq7
    regex-tdfa-1.3.2.4-16fa8fV2J4jFJDn5KyghaT
    safe-0.3.21-29OHNU5kqwB6czdAzMhG9H
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.5-HrmUIRGlGcKACyqFcQzDDh
    tasty-hunit-0.10.1-GMUJJktWtApWbp9mz5955 template-haskell-2.19.0.0
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2
    text-ansi-0.3.0.1-1PBKPvU7VWgIChvCMsf8lR time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    uglymemo-0.1.0.1-8AX9zjlFnnmIrnTboBgOzO
    unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY
    utf8-string-1.0.2-JoSH3X8qo5Q4jcipebjMdu

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
